# python 05_supervised_accvsN.py data.dat
# Plot acc vs N

import sys
import numpy as np
import pylab as pl
from sklearn import svm, cross_validation

data = np.genfromtxt(sys.argv[1], delimiter=',', skip_header = 1)
classes, u, g, r, i, z = data[:, 0], data[:, 1], data[:, 2], data[:, 3], data[:, 4], data[:, 5] 
colors = u - g, g - r, r - i, i - z
names = np.array(["u - g", "g - r", "r - i", "i - z"])
cl_names = ["stars", "quasars", "white dwarfs"]
N = len(classes)
data_svm = np.array(colors).transpose()

clf = svm.SVC(kernel = "linear")

Ns = np.array([20, 100, 1000, 5000, 10000])
scores = np.zeros(len(Ns))
stds = np.zeros(len(Ns))
i_s = np.arange(N)
np.random.shuffle(i_s)
for i in range(len(Ns)):
    N = Ns[i]
    i1 = i_s[:N]
    scores_i = cross_validation.cross_val_score(clf, data_svm[i1], classes[i1], cv=10)
    scores[i] = scores_i.mean()
    stds[i] = scores_i.std()

pl.clf()
fig = pl.figure()
ax = fig.add_subplot(1,1,1)
ax.errorbar (Ns, scores, yerr = stds)
ax.set_xscale("log")
ax.set_xlabel("N")
ax.set_ylabel("Accuracy")
ax.set_xlim([10, 15000])
pl.savefig ("accvsN")
