# python 06_supervised_choosingC.py data.dat
# Plot acc vs C

import sys
import numpy as np
import pylab as pl
from sklearn import svm, cross_validation
from sklearn.grid_search import GridSearchCV

data = np.genfromtxt(sys.argv[1], delimiter=',', skip_header = 1)
classes, u, g, r, i, z = data[:, 0], data[:, 1], data[:, 2], data[:, 3], data[:, 4], data[:, 5] 
colors = u - g, g - r, r - i, i - z
names = np.array(["u - g", "g - r", "r - i", "i - z"])
cl_names = ["stars", "quasars", "white dwarfs"]

N = 1000
i_s = np.arange(len(classes))
np.random.shuffle(i_s)
i_s = i_s[:N]
data_svm = np.array(colors).transpose()[i_s]
classes = classes[i_s]

C_range = 10. ** np.arange(-5, 5)
param_grid = dict(C=C_range)
grid = GridSearchCV(svm.SVC(kernel = "linear"), param_grid=param_grid, cv=10)
grid.fit (data_svm, classes)

print "The best classifier is: ", grid.best_estimator_
# plot the scores of the grid
# grid_scores_ contains parameter settings and scores
score_dict = grid.grid_scores_

# We extract just the scores
scores = [x[1] for x in score_dict]
print scores

pl.clf()
fig = pl.figure()
ax = fig.add_subplot(1,1,1)
ax.plot (C_range, scores)
ax.set_xscale("log")
ax.set_xlabel("C")
ax.set_ylabel("Accuracy")
pl.savefig ("accvsC")
