# python 07_supervised_RBF.py data.dat
# Plot acc vs C and gamma

import sys
import numpy as np
import pylab as pl
from sklearn import svm, cross_validation
from sklearn.grid_search import GridSearchCV

data = np.genfromtxt(sys.argv[1], delimiter=',', skip_header = 1)
classes, u, g, r, i, z = data[:, 0], data[:, 1], data[:, 2], data[:, 3], data[:, 4], data[:, 5] 
colors = u - g, g - r, r - i, i - z
names = np.array(["u - g", "g - r", "r - i", "i - z"])
cl_names = ["stars", "quasars", "white dwarfs"]

N = 1000
i_s = np.arange(len(classes))
np.random.shuffle(i_s)
i_s = i_s[:N]
data_svm = np.array(colors).transpose()[i_s]
classes = classes[i_s]

C_range = 10. ** np.arange(-5, 5)
gamma_range = 10. ** np.arange(-5, 5)
param_grid = dict(gamma=gamma_range, C=C_range)
grid = GridSearchCV(svm.SVC(kernel = "rbf"), param_grid=param_grid, cv=10)
grid.fit (data_svm, classes)

print "The best classifier is: ", grid.best_estimator_
# plot the scores of the grid
# grid_scores_ contains parameter settings and scores
score_dict = grid.grid_scores_

# We extract just the scores
scores = [x[1] for x in score_dict]
scores = np.array(scores).reshape(len(C_range), len(gamma_range))

# Make a nice figure
pl.figure(figsize=(8, 6))
pl.subplots_adjust(left=0.15, right=0.95, bottom=0.15, top=0.95)
pl.imshow(scores, interpolation='nearest', cmap=pl.cm.gist_heat)
pl.xlabel('gamma')
pl.ylabel('C')
pl.colorbar()
pl.xticks(np.arange(len(gamma_range)), gamma_range, rotation=45)
pl.yticks(np.arange(len(C_range)), C_range)
pl.savefig("RBF_C_gamma")
